@@ -1,14 +1,14 @@
 #
 # This file is part of Config-Model-Systemd
 #
-# This software is Copyright (c) 2015-2018 by Dominique Dumont.
+# This software is Copyright (c) 2015-2020 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Backend::Systemd ;
-$Config::Model::Backend::Systemd::VERSION = '0.239.1';
+$Config::Model::Backend::Systemd::VERSION = '0.246.1';
 use strict;
 use warnings;
 use 5.010;
@@ -127,10 +127,11 @@ sub read_systemd_units {
         $self->config_dir($dir);
 
         foreach my $file ($dir->children($filter) ) {
+            my $file_name = $file->basename();
             my $unit_name = $file->basename($filter);
-            $logger->trace( "checking unit $unit_name from $file (layered mode))");
-            if ($select_unit ne '*' and $unit_name !~ /$select_unit/) {
-                $logger->trace( "filtered out unit $unit_name from $file (layered mode))");
+            $logger->trace( "checking unit $file_name from $file (layered mode) against $select_unit");
+            if ($select_unit ne '*' and $file_name !~ /$select_unit/) {
+                $logger->trace( "unit $file_name from $file (layered mode) does not match $select_unit");
                 next;
             }
             my ($unit_type) = ($file =~ $filter);
@@ -151,18 +152,22 @@ sub read_systemd_units {
     my $found = 0;
     foreach my $file ($dir->children($filter) ) {
         my ($unit_type,$dot_d) = ($file =~ $filter);
+        my $file_name = $file->basename();
         my $unit_name = $file->basename($filter);
-        next if ($select_unit ne '*' and $unit_name !~ /$select_unit/);
+
+        next if ($select_unit ne '*' and $file_name !~ /$select_unit/);
+        $logger->trace( "checking $file against $select_unit");
+
         if ($file->realpath eq '/dev/null') {
-            $logger->debug("unit $unit_type name $unit_name from $file is disabled");
+            $logger->warn("unit $unit_type name $unit_name from $file is disabled");
             $self->node->load(step => qq!$unit_type:"$unit_name" disable=1!, check => $args{check} ) ;
         }
         elsif ($dot_d and $file->child('override.conf')->exists) {
-            $logger->debug("registering unit $unit_type name $unit_name from override file");
+            $logger->warn("registering unit $unit_type name $unit_name from override file");
             $self->node->load(step => qq!$unit_type:"$unit_name"!, check => $args{check} ) ;
         }
         else {
-            $logger->debug("registering unit $unit_type name $unit_name from $file");
+            $logger->warn("registering unit $unit_type name $unit_name from $file");
             $self->node->load(step => qq!$unit_type:"$unit_name"!, check => $args{check} ) ;
         }
         $found++;
@@ -170,6 +175,7 @@ sub read_systemd_units {
 
     if (not $found) {
         # no service exists, let's create them.
+        $user_logger->warn( "No unit '$select_unit' found in $dir, creating one...");
         my ($service_name, $unit_type) =  split /\./, $select_unit;
         my @to_create = $unit_type ? ($unit_type) : @service_types;
         $service_name //= $select_unit;
@@ -237,7 +243,7 @@ Config::Model::Backend::Systemd - R/W backend for systemd configurations files
 
 =head1 VERSION
 
-version 0.239.1
+version 0.246.1
 
 =head1 SYNOPSIS
 
@@ -276,7 +282,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015-2018 by Dominique Dumont.
+This software is Copyright (c) 2015-2020 by Dominique Dumont.
 
 This is free software, licensed under:
 
