@@ -1,14 +1,14 @@
 #
 # This file is part of Config-Model-Systemd
 #
-# This software is Copyright (c) 2015-2018 by Dominique Dumont.
+# This software is Copyright (c) 2015-2020 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Backend::Systemd::Layers;
-$Config::Model::Backend::Systemd::Layers::VERSION = '0.239.1';
+$Config::Model::Backend::Systemd::Layers::VERSION = '0.246.1';
 use Mouse::Role;
 
 
@@ -33,6 +33,8 @@ sub default_directories {
             '/etc/systemd/system.conf.d/',
             '/run/systemd/system.conf.d/',
             '/lib/systemd/system.conf.d/',
+            # not documented but used to symlink to real files
+            '/etc/systemd/system/',
             # path found on Debian
             '/lib/systemd/system/',
         );
@@ -57,7 +59,7 @@ Config::Model::Backend::Systemd::Layers - Role that provides Systemd default dir
 
 =head1 VERSION
 
-version 0.239.1
+version 0.246.1
 
 =head1 SYNOPSIS
 
@@ -83,7 +85,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015-2018 by Dominique Dumont.
+This software is Copyright (c) 2015-2020 by Dominique Dumont.
 
 This is free software, licensed under:
 
