@@ -1,14 +1,14 @@
 #
 # This file is part of Config-Model-Systemd
 #
-# This software is Copyright (c) 2015-2018 by Dominique Dumont.
+# This software is Copyright (c) 2015-2020 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Backend::Systemd::Unit ;
-$Config::Model::Backend::Systemd::Unit::VERSION = '0.239.1';
+$Config::Model::Backend::Systemd::Unit::VERSION = '0.246.1';
 use strict;
 use warnings;
 use 5.010;
@@ -51,17 +51,19 @@ sub read {
     my $unit_name = $self->node->index_value;
 
     $self->node->instance->layered_start;
-    my $root = $args{root} || path('.');
+    my $root = $args{root} || path('/');
+    my $cwd = $args{root} || path('.');
 
     # load layers for this service
     foreach my $layer ($self->default_directories) {
-        my $layer_dir = $root->child($layer);
+        my $local_root = $layer =~ m!^/! ? $root : $cwd;
+        my $layer_dir = $local_root->child($layer);
         next unless $layer_dir->is_dir;
 
         my $layer_file = $layer_dir->child($unit_name.'.'.$unit_type);
         next unless $layer_file->exists;
 
-        $logger->debug("reading default layer from unit $unit_type name $unit_name from $layer_file");
+        $logger->warn("reading default layer from unit $unit_type name $unit_name from $layer_file");
         $self->load_ini_file(%args, file_path => $layer_file);
 
         # TODO: may also need to read files in
@@ -202,7 +204,6 @@ sub write {
     my $service_path;
     if ($app eq 'systemd') {
         my $dir = $args{file_path}->parent->child("$unit_name.$unit_type.d");
-        $dir->mkpath;
         $service_path = $dir->child('override.conf');
     }
     else {
@@ -243,7 +244,7 @@ Config::Model::Backend::Systemd::Unit - R/W backend for systemd unit files
 
 =head1 VERSION
 
-version 0.239.1
+version 0.246.1
 
 =head1 SYNOPSIS
 
@@ -282,7 +283,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015-2018 by Dominique Dumont.
+This software is Copyright (c) 2015-2020 by Dominique Dumont.
 
 This is free software, licensed under:
 
